GPS receiver, SkyTraq Venus 6, SUP500F with internal smart antenna, reads the raw NMEA information and transfers only the GPGGA info to the laptop. Simple example.

Dependencies:   mbed

Files at this revision

API Documentation at this revision

Comitter:
GerritPathuis
Date:
Sun Mar 13 13:39:00 2011 +0000
Parent:
0:92567322923d
Commit message:
Minot text modification

Changed in this revision

main.cpp Show annotated file Show diff for this revision Revisions of this file
--- a/main.cpp	Sun Jan 02 18:57:24 2011 +0000
+++ b/main.cpp	Sun Mar 13 13:39:00 2011 +0000
@@ -13,13 +13,13 @@
 // 65 channel SUP500F 10Hz GPS receiver with integrated Smart antenna
 // See www.sparkfun.com GPS-09758 for details and documentation
 // Hardware information
 // PUF500F pin1 -------------MBED p13
 // PUF500F pin2 -------------MBED p14
 // PUF500F pin3 -------------MBED GND
 // PUF500F pin4 -------------MBED Vout (3.3V @ 75mAmp)
 // PUF500F pin5 -------------MBED Vout
 // PUF500F pin6 -----LED-----MBED GND
 // PUF500F pin7 -------------MBED GND
 //
 // IMPORTANT REMARK-------------------------------------------------
 // This receiver has an integrated antenna and will not work when
@@ -28,7 +28,7 @@
 //------------------------------------------------------------------
 
 Serial pc(USBTX, USBRX);    // tx, rx
-Serial puf500(p13, p14);    // tx, rx
+Serial sup500(p13, p14);    // tx, rx
 
 char nmea[MESS_LEN] = {0x00};   // raw message from the GPS receiver
 char gp[MAX_STR][STR_LEN];      // 40 strings, length is 30
@@ -41,8 +41,8 @@
     pc.baud(9600);
     pc.format(8,Serial::None,1);
 
-    puf500.baud(9600);
-    puf500.format(8,Serial::None,1);
+    sup500.baud(9600);
+    sup500.format(8,Serial::None,1);
 
     pc.printf("Start lurking...\n\r");
     while (1) {
@@ -54,7 +54,7 @@
 
 //--------------------read nmea from GPS unit--------------------
 void read_nmea(void) {
-    puf500.scanf("%s,",nmea);
+    sup500.scanf("%s,",nmea);
     //pc.printf("Raw message %s \n\r",nmea); // just for testing
 }
@@ -13,13 +13,13 @@
 // See www.sparkfun.com GPS-09758 for details and documentation
 // Hardware information
-// PUF500F pin1 -------------MBED p13
-// PUF500F pin2 -------------MBED p14
-// PUF500F pin3 -------------MBED GND
-// PUF500F pin4 -------------MBED Vout (3.3V @ 75mAmp)
-// PUF500F pin5 -------------MBED Vout
-// PUF500F pin6 -----LED-----MBED GND
-// PUF500F pin7 -------------MBED GND
+// SUP500F pin1 -------------MBED p13
+// SUP500F pin2 -------------MBED p14
+// SUP500F pin3 -------------MBED GND
+// SUP500F pin4 -------------MBED Vout (3.3V @ 75mAmp)
+// SUP500F pin5 -------------MBED Vout
+// SUP500F pin6 -----LED-----MBED GND
+// SUP500F pin7 -------------MBED GND
 //
 // IMPORTANT REMARK-------------------------------------------------